#!/bin/bash

# Set up some environment parameters for later use
# Please be aware that these environmental variables only exist within the scope of this Jupyter document.
export LEASE_NAME="$USER-tinytail"
export SERVER_NAME="$USER-tinytail-server"
export PRIVATE_NETWORK_NAME="sharednet1"
export PUBLIC_NETWORK_NAME="public"
export SSHKEY_FILE="$HOME/work/.ssh/work/$USER-chameleon"
export SSHKEY_NAME="ChameleonKey"
export NODE_TYPE="compute_haswell"
export NUM_SERVERS=1

# Create a lease on Chameleon
blazar lease-create --physical-reservation \
   min="$NUM_SERVERS",max="$NUM_SERVERS",resource_properties='["=", "$node_type", "'"$NODE_TYPE"'"]' "$LEASE_NAME"

# Make sure the lease is up
lease_status=""

# Lease in a sorry state
while [[ $lease_status == "TERMIN"* ]] || [[ $lease_status == "ERROR" ]] 
do
   echo "Lease it is in a sorry state. Restarting it."
   # Delete old lease
   blazar lease-delete "$LEASE_NAME"
   blazar lease-create --physical-reservation \
      min=1,"max=$MAX_SERVERS",resource_properties='["=", "$node_type", "$NODE_TYPE"]' "$LEASE_NAME"
   lease_status=$(blazar lease-show --format value -c status "$LEASE_NAME")
done
echo "Lease creation successfuly started."

# Now wait for lease to be ready before going to the next step
while [[ $lease_status != "ACTIVE" ]]
do
   sleep 5
   lease_status=$(blazar lease-show --format value -c status "$LEASE_NAME")
done

echo "Lease $LEASE_NAME is ready for business"

# Get the lease ID
lease_id=$(blazar lease-show  --format value -c  reservations "$LEASE_NAME" |grep \"id\"| cut -d \" -f4)

# Get the network ID associated with sharednet1
network_id=$(openstack network show --format value -c id $PRIVATE_NETWORK_NAME)

# Check the SSH key status
keys=$(openstack keypair list | grep $SSHKEY_NAME)
if [[ $keys == *"$SSHKEY_NAME"* ]]; then
    echo "SSH key $SSHKEY_NAME already exists"
else
    # If non-existent, create one
    ssh-keygen -t rsa -b 4096  -P '' -C $SSHKEY_NAME -f $SSHKEY_FILE
    openstack keypair create --public-key $SSHKEY_FILE.pub  $SSHKEY_NAME
    echo "SSh key $SSHKEY_NAME created"
fi

# Create a baremetal server
openstack server create \
  --flavor "baremetal" \
  --image "CC-Ubuntu16.04" \
  --nic net-id="$network_id" \
  --hint reservation="$lease_id" \
  --key-name="$SSHKEY_NAME" \
  --security-group default  \
  "$SERVER_NAME"
